@@ -9,7 +9,6 @@ from .test_case import TestCase
 from .output import Output
 from .check import Check, CheckResult, CheckError
 from .results import TestCaseResult, TestCaseSummary, EvaluationRunResult, EvaluationSummary
-from .experiments import ExperimentMetadata
 
 __all__ = [
     "Check",
@@ -17,7 +16,6 @@ __all__ = [
     "CheckResult",
     "EvaluationRunResult",
     "EvaluationSummary",
-    "ExperimentMetadata",
     "Output",
     "TestCase",
     "TestCaseResult",
